#!/usr/bin/env bash

ABSDIR="$( dirname "$(readlink -f -- "$0")" )"
source ${ABSDIR}/../functions.sh
source ${ABSDIR}/vars.sh

ensure_pwd_is_scriptdir
ensure_not_root

buildfolder=/tmp/gitea-$$

if ! podman image exists ${gitea_image}:${gitea_version}; then
    mkdir ${buildfolder} &&
        curl -sSfL -- "https://dl.gitea.io/gitea/${gitea_version}/gitea-src-${gitea_version}.tar.gz" | tar xz --strip-components=1 -C ${buildfolder}/ && {
	sed_in_place "^FROM golang" "FROM docker.io/library/golang" ${buildfolder}/Dockerfile
        sed_in_place "^FROM alpine" "FROM docker.io/library/alpine" ${buildfolder}/Dockerfile
	TMPDIR=${HOME} podman image build -t ${gitea_image}:${gitea_version} -f ${buildfolder}/Dockerfile ${buildfolder}
    }
    rm -rf ${buildfolder}
    podman image prune -a -f --filter dangling=true
    podman image prune -a -f --filter intermediate=true
    podman image rm -f $(podman images -a -q -- docker.io/library/golang)
    podman image rm -f $(podman images -a -q -- docker.io/library/alpine)
else
    echo "Image ${gitea_image}:${gitea_version} already built"
fi

oci_push_to_registry ${gitea_image}:${gitea_version}
